@@ -58,6 +58,9 @@
 #' for the default ggplot2 theme)
 #' @param na.rm A logical (TRUE) to control removal of missing values. Passed to
 #' \link[ggplot2]{geom_line} and \link[ggplot2]{geom_point}
+#' 
+#' @param mapping (passed in ggplot.ggdend) Default list of aesthetic mappings to use for plot. If not specified, must be supplied in each layer added to the plot.
+#' @param environment (passed in ggplot.ggdend) deprecated / ignored.
 #'
 #' @details
 #'
@@ -479,10 +482,10 @@ prepare.ggdend <- function(data, ...) {
 
 #' @export
 #' @rdname ggdend
-ggplot.ggdend <- function(data, segments = TRUE, labels = TRUE, nodes = TRUE,
+ggplot.ggdend <- function(data = NULL, mapping = aes(), ..., segments = TRUE, labels = TRUE, nodes = TRUE,
                           horiz = FALSE, theme = theme_dendro(),
                           offset_labels = 0, na.rm = TRUE,
-                          ...) {
+                          environment = parent.frame())  {
   #    library(dendextend)
   #    library(ggdendro)
   # Get all the ggplot2 functions ready: (this could have been evoided if ggplot2 was imported...)
@@ -518,59 +521,64 @@ ggplot.ggdend <- function(data, segments = TRUE, labels = TRUE, nodes = TRUE,
 
 
 
-  p <- ggplot()
+  p <- ggplot(mapping = mapping, ...)
 
 
   # ggplot() +
   #    geom_segment(data = data$segments,
   #                 aes(x = x, y = y, xend = xend, yend = yend, colour = col, linetype = lty, size = lwd)) +
-  #    guides(linetype = FALSE, col = FALSE) +
+  #    guides(linetype = "none", col = "none") +
   #    scale_colour_identity() + scale_size_identity()  + scale_linetype_identity() +
   #    geom_text(data = data$labels,
   #              aes(x = x, y = y, label = label), angle = angle, hjust = 1) #  ,angle = 90
 
 
   if (segments) {
-    p <- p + geom_segment(
-      data = data$segments, na.rm = na.rm,
-      aes_string(
-        x = "x", y = "y", xend = "xend", yend = "yend",
-        colour = "col", linetype = "lty", size = "lwd"
-      ),
-      lineend = "square"
-    ) +
-      guides(linetype = FALSE, col = FALSE) +
-      scale_colour_identity() + scale_size_identity() + scale_linetype_identity()
+     p <- p + geom_segment(
+        data = data$segments, na.rm = na.rm,
+        aes(
+           x = .data$x, y = .data$y, xend = .data$xend, yend = .data$yend,
+           colour = .data$col, linetype = .data$lty, linewidth = .data$lwd
+        ),
+        lineend = "square"
+     ) +
+        guides(linetype = "none", col = "none") +
+        scale_colour_identity() + scale_size_identity() + scale_linetype_identity()
   }
-
+  
   if (nodes) {
-    p <- p + geom_point(
-      data = data$nodes, na.rm = na.rm,
-      aes_string(x = "x", y = "y", colour = "col", shape = "pch", size = "cex")
-    ) +
-      guides(shape = FALSE, col = FALSE, size = FALSE) +
-      # scale_colour_identity() + scale_size_identity()  +
-      scale_shape_identity()
+     p <- p + geom_point(
+        data = data$nodes, na.rm = na.rm,
+        aes(x = .data$x, y = .data$y, colour = .data$col, shape = .data$pch, size = .data$cex)
+     ) +
+        guides(shape = "none", col = "none", size = "none") +
+        # scale_colour_identity() + scale_size_identity()  +
+        scale_shape_identity()
   }
   # http://docs.ggplot2.org/0.9.3.1/geom_point.html
 
   #    p +  geom_point(data = data$nodes,
   #                    aes_string(x = "x", y = "y", colour = "col", shape = "pch", size = 3.5)) +
-  #       guides(shape = FALSE, col = FALSE, size = FALSE) +
+  #       guides(shape = "none", col = "none", size = "none") +
   #       scale_shape_identity()
 
 
   if (labels) {
-    # default size is 5!  http://sape.inf.usi.ch/quick-reference/ggplot2/geom_text
-    data$labels$cex <- 5 * data$labels$cex
-    data$labels$y <- data$labels$y + offset_labels
-    p <- p + geom_text(
-      data = data$labels, aes_string(
-        x = "x",
-        y = "y", label = "label", colour = "col", size = "cex"
-      ),
-      hjust = hjust, angle = angle
-    )
+     # default size is 5!  http://sape.inf.usi.ch/quick-reference/ggplot2/geom_text
+     data$labels$cex <- 5 * data$labels$cex
+     data$labels$y <- data$labels$y + offset_labels
+     p <- p + geom_text(
+        data = data$labels, 
+        aes(
+           x = .data$x,
+           y = .data$y, 
+           label = .data$label, 
+           colour = .data$col, 
+           size = .data$cex
+        ),
+        hjust = hjust, 
+        angle = angle
+     )
   }
   # p <- p + scale_x_discrete(labels = data$labels$label)
   # if (horiz) {
